jk_testing
==========

Introduction
------------

This python module provides a simple to use infrastructure for running unit tests.

Information about this module can be found here:

* [github.org](https://github.com/jkpubsrc/python-module-jk-testing)
* [pypi.python.org](https://pypi.python.org/pypi/jk_testing)

How to use this module
----------------------

### ....

....

Contact Information
-------------------

Author(s):

* Jürgen Knauth: pubsrc@binary-overflow.de

License
-------

This software is provided under the following license:

* Apache Software License 2.0



